{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf mkMerge mkThenElse;
  annuaire = config.r6d.machines;
  currentMachine = annuaire."${config.networking.hostName}";
  flags = currentMachine.configurationFlags;
in

mkIf currentMachine.profiles.isDesktopEnvironment {

  # Paquets
  environment.systemPackages = with pkgs; [
    # Environement de bureau
    arandr          # interface graphique pour xrandr
    wmname          # pour définir le nom du gestionnaire de fenêtre (utile pour java)
    #kde4.ksnapshot # capture d'écran
    xclip           # manipulation du clipboard X depuis la console
    xorg.xbacklight # pour gérer la luminosité de l'écran
    xorg.xev        # pour repérer les codes + noms standard des actions clavier/souris
    xorg.xkill      # pour 'tuer une application'

    ## Gestionnaire de fenêtre & Thème
    gnome3.adwaita-icon-theme  # thème d'icone - semble fonctionner avec spaceFM

    ## Manipulation de fichier
    #kde5.dolphin          # gestionnaire de fichiers graphique
    #kde5.dolphin-plugins  # gestionnaire de fichiers graphique
    pcmanfm               # gestionnaire de fichiers graphique
    spaceFM               # gestionnaire de fichiers graphique
    #vifm                  # gestionnaire de fichiers basé sur VIM (console)

    ## Terminal
    sakura                # terminal
  ];

  # Polices supplémentaires
  fonts.fonts = with pkgs; [
    fira            # police créée pour Firefox
    fira-code       # idem fira-mono + ligatures pour la programmation
    fira-mono       # dérivée de fira en monospace
    font-awesome_5  # Jeux de police, utilisé avec Latex
    hack-font       # police monospace créée explicitement pour coder
    hasklig         # police dérivée de source-code-pro mais avec des ligatures
  ];

  # Paquets avec setuid root
  security.wrappers = {
    # pour le montage des media amovibles
    devmon.source = "${pkgs.udevil}/bin/devmon";
    udevil.source = "${pkgs.udevil}/bin/udevil"; # utilisé par spacefm
    # vérouiller l''écran. "cannot disable the out-of-memory killer for this process (make sure to suid or sgid slock)" --> en root
    slock.source = "${pkgs.slock}/bin/slock";
  };
}
